@@ -5,6 +5,7 @@ import more_itertools
 import pendulum
 
 from .collection import Collection
+from .feeds import RSSFeed
 from .page import Page
 
 
@@ -12,6 +13,7 @@ class BlogPost(Page):
     """Page Like object with slight modifications to work with BlogPosts."""
 
     list_attrs = ["tags"]
+    feed = RSSFeed
 
     def __init__(self, **kwargs):
         """
@@ -72,6 +74,7 @@ class Blog(Collection):
         - Rename the archive items so they are not private
     """
 
+    feed = RSSFeed
     content_type: typing.Type[BlogPost] = BlogPost
     sort_reverse: bool = True
     sort_by = "date_published"
