@@ -39,7 +39,7 @@ class Site:
     Sites also contain global variables that can be applied in templates.
     """
 
-    output_path: Path = Path("output")
+    path: Path = Path("output")
     """Path to write rendered content."""
 
     # Vars that will be passed into the render functions
@@ -54,13 +54,9 @@ class Site:
         pad = Padding(f"Site Config Keys Imported: {[x for x in self.site_vars]}", 1)
         rprint(pad)
 
-        self.output_path.mkdir(exist_ok=True, parents=True)
-
         if static:
             self.render_static(static)
 
-
-
     def render_collection(self, collection: typing.Type[Collection]) -> None:
         """Add a class to your ``self.collections``
         iterate through a classes ``content_path`` and create a classes ``Page``-like
@@ -80,7 +76,7 @@ class Site:
         )
 
         _collection = collection()
-        collection_path = self.output_path / _collection.output_path
+        collection_path = self.path / _collection.output_path
         creating_output_path = p.add_task(
             f"[dark_olive_green1]- creating {collection_path=}", total=1
         )
@@ -115,7 +111,7 @@ class Site:
                 link=self.site_vars["SITE_URL"],
                 pages=_collection.pages,
             )
-            feed.render(path=self.output_path, **self.site_vars, **collection_vars)
+            feed.render(path=self.path, **self.site_vars, **collection_vars)
             p.update(create_feed, completed=1)
 
         p.update(build_collection, advance=1)
@@ -172,8 +168,8 @@ class Site:
         with p:
 
             _page = page(**self.site_vars)
-            _page.render(path=self.output_path, **page.__dict__)
+            _page.render(path=self.path, **page.__dict__)
 
     def render_static(self, directory) -> None:
         """Copies a Static Directory to the output folder"""
-        return shutil.copytree(directory, self.output_path / directory, dirs_exist_ok=True)
+        return shutil.copytree(directory, self.path / directory, dirs_exist_ok=True)
